@@ -20,6 +20,8 @@ wheel = "{}/WHEEL".format(dist_info)
 record = "{}/RECORD".format(dist_info)
 content = {
     logic: "def do():\n    print('greetings from {}')".format(name),
+}
+metadata = {
     metadata: """
         Metadata-Version: 2.1
         Name: {}
@@ -62,6 +64,16 @@ def build_wheel(wheel_directory, metadata_directory=None, config_settings=None):
     with ZipFile(path, "w") as zip_file_handler:
         for arc_name, data in content.items():  # pragma: no branch
             zip_file_handler.writestr(arc_name, dedent(data).strip())
+        if metadata_directory is not None:
+            for sub_directory, _, filenames in os.walk(metadata_directory):
+                for filename in filenames:
+                    zip_file_handler.write(
+                        os.path.join(metadata_directory, sub_directory, filename),
+                        os.path.join(sub_directory, filename),
+                    )
+        else:
+            for arc_name, data in metadata.items():  # pragma: no branch
+                zip_file_handler.writestr(arc_name, dedent(data).strip())
     print("created wheel {}".format(path))
     return base_name
 
